# 店铺接口服务定义
---------------------


## 获取店铺列表
> 接口名： `/ShopsRest/getShopList`

### 入参
```json
{
 "page":2,
 "size":12,
 "supplierId":950,
 "brandId":928,
 "checkStatus":100,
 "operationStatus":1,
 "checkStatusArr":"100,200,900"
}
```
-------------------------
|属性名称|类型|例子|说明| 
|--------|----|----|----|
|page|int|2|第几页|
|size|int|50|每页条数|
|supplierId|int|950|供应商ID|
|brandId|int|928|品牌ID|
|checkStatus|int|100|审核状态；100 暂存 200 待审核 300 审核通过 900 驳回|
|operationStatus|int|1|操作状态； 1 店铺未创建 2 店铺已创建|
|checkStatusArr|String|200,300|必须包含的状态|
---------------------------


### 返回

```json

{
  "code": 200,
  "data": {
    "list": [
      {
        "checkStatus": 200,
        "createTime": "2015-11-27 15:45:19",
        "shopName": "Case Scenario",
        "shopRelationList": [
          {
            "brandId": 409,
            "brandName": "Case Scenario",
            "brandNameCn": "",
            "brandNameEn": "Case Scenario",
            "brandStatus": 1,
            "supplierId": 0,
            "supplierStatus": 0
          }
        ],
        "shopsId": 31,
        "status": 1,
        "updateTime": "2015-12-08 19:20:44"
      }
    ],
    "page": 1,
    "size": 10,
    "total": 79,
    "totalPage": 8
  },
  "message": "操作成功"
}
```

---------------------------------------------------------------------------------------------------------

## 获取店铺详情

> 接口名: `/ShopsRest/getShopDetailById`

### 入参

-------------------------
|属性名称|类型|例子|说明| 
|--------|----|----|----|
|shopsId|int|15|店铺ID|
-----------------------------

### 返回

```json

{
  "code": 200,
  "data": {
    "checkStatus": 200,
    "createTime": "2016-01-29 23:11:00",
    "otherUrl": "other,other2",
    "shopAddress": "地址1,地址2",
    "shopDomain": "shopDomain2311",
    "shopIntro": "shopIntro",
    "shopLogo": "http:///yhfairshopLogo?imageView/1/w/200/h/200",
    "shopName": "店铺名称1234",
    "shopNature": 1,
    "shopRelationList": [
      {
        "agreementEndTime": "2016-03-31 00:00:00",
        "brandId": 178,
        "brandName": "Artanky",
        "brandNameCn": "",
        "brandNameEn": "Artanky ",
        "brandStatus": 1,
        "isFreeze": "N",
        "supplierId": 480,
        "supplierName": "成都朋克汉堡服装有限公司",
        "supplierStatus": 300
      },
      {
        "agreementEndTime": "2017-01-31 00:00:00",
        "brandId": 355,
        "brandName": "TMCAZ",
        "brandNameCn": "磨叽星人",
        "brandNameEn": "TMCAZ",
        "brandStatus": 1,
        "isFreeze": "N",
        "supplierId": 310,
        "supplierName": "上海贺王工贸实业公司",
        "supplierStatus": 300
      },
      {
        "agreementEndTime": "2016-12-19 00:00:00",
        "brandId": 1389,
        "brandName": "WWTorres",
        "brandNameCn": "",
        "brandNameEn": "WWTorres",
        "brandStatus": 1,
        "isFreeze": "N",
        "supplierId": 1226,
        "supplierName": "上海矩乐文化发展有限公司",
        "supplierStatus": 300
      }
    ],
    "shopsId": 454,
    "shopsType": 2,
    "status": 0,
    "updateTime": "2016-01-29 23:27:05",
    "websiteUrl": "https,https2"
  },
  "message": "操作成功"
}
```

---------------------------------------------------------------------------------------------------------

## 创建店铺

> 接口名：`/ShopsRest/addShops`

### 入参

-------------------------
|属性名称|类型|例子|说明| 
|--------|----|----|----|
|shopName|String|得宝旗舰店|店铺名称|
|shopNature|int|1|店铺性质(1 旗舰店 2 专卖店)|
|shopDomain|String|debao|店铺域名|
|createPid|int|1|创建人ID|
|shopsType|int|1|店铺模式(1-单品店；2-多品店)|
|shopLogo|String|http://img11.static.yhbimg.com/yhb-img01/2015/09/11/02/01f42dff5d5bd383af1025eea1218cbccc.jpg?imageView/{mode}/w/{width}/h/{height}|店铺logo|
|shopIntro|String|秉承以设计为核心的创新理念，用专业的思维方式将自然与科技、传统与革新、技艺与时尚三者良好融合，着重面料材质与软式廓型的品质互动，更好的诠释“less is more”的设计理念。|店铺简介|
|websiteUrl|JSON数组|["www.paperworks.com.cn"]||
|otherUrl|JSON数组|["www.paperworks.com.cn","https:\/\/jnby.tmall.com\/"]||
|shopAddress|JSON数组|||
|onCheck|int|1|是否需要审核（1-是；0-否）|
|shopRelation|JSON数组||品牌与供应商关系|
---------------------

shopRelation的json格式为：
``` json

"shopRelation":[
		{
			"brandId":355,
			"supplierId":310,
			"agreementEndTime":1485792000
		},
		{
			"brandId":1389,
			"supplierId":1226,
			"agreementEndTime":1482076800
		}
	]
```
	
### 返回
返回码code为200就是成功，其余为失败。

``` json
{
  "code": 200,
  "message": "success."
}
```

---------------------------------------------------------------------------------------------------------

## 修改店铺

> 接口名：`/ShopsRest/updateShops`

### 入参

-------------------------
|属性名称|类型|例子|说明| 
|--------|----|----|----|
|shopsId|int|2|店铺id|
|shopName|String|得宝旗舰店|店铺名称|
|shopNature|int|1|店铺性质(1 旗舰店 2 专卖店)|
|shopDomain|String|debao|店铺域名|
|createPid|int|1|创建人ID|
|shopsType|int|1|店铺模式(1-单品店；2-多品店)|
|shopLogo|String|http://img11.static.yhbimg.com/yhb-img01/2015/09/11/02/01f42dff5d5bd383af1025eea1218cbccc.jpg?imageView/{mode}/w/{width}/h/{height}|店铺logo|
|shopIntro|String|秉承以设计为核心的创新理念，用专业的思维方式将自然与科技、传统与革新、技艺与时尚三者良好融合，着重面料材质与软式廓型的品质互动，更好的诠释“less is more”的设计理念。|店铺简介|
|websiteUrl|JSON数组|["www.paperworks.com.cn"]||
|otherUrl|JSON数组|["www.paperworks.com.cn","https:\/\/jnby.tmall.com\/"]||
|shopAddress|JSON数组|||
|onCheck|int|1|是否需要审核（1-是；0-否）|
|shopRelation|JSON数组||品牌与供应商关系|
---------------------

shopRelation的json格式为：
``` json

"shopRelation":[
		{
			"brandId":355,
			"supplierId":310,
			"agreementEndTime":1485792000
		},
		{
			"brandId":1389,
			"supplierId":1226,
			"agreementEndTime":1482076800
		}
	]
```
	
### 返回
返回码code为200就是成功，其余为失败。

``` json
{
  "code": 200,
  "message": "success."
}
```

---------------------------------------------------------------------------------------------------------

## 关店

> 接口名: `/ShopsRest/closeShops`

### 入参

-------------------------
|属性名称|类型|例子|说明| 
|--------|----|----|----|
|shopsId|int|15|店铺ID|
-----------------------------

### 返回

```json

{
  "code": 200,
  "message": "操作成功"
}

```

---------------------------------------------------------------------------------------------------------

## 开店

> 接口名: `/ShopsRest/openShops`

### 入参

-------------------------
|属性名称|类型|例子|说明| 
|--------|----|----|----|
|shopsId|int|15|店铺ID|
-----------------------------

### 返回

```json

{
  "code": 200,
  "message": "操作成功"
}

```

---------------------------------------------------------------------------------------------------------

## 审核通过

> 接口名: `/ShopsRest/checkShopPass`

### 入参

-------------------------
|属性名称|类型|例子|说明| 
|--------|----|----|----|
|shopsId|int|15|店铺ID|
-----------------------------

### 返回

```json

{
  "code": 200,
  "message": "操作成功"
}

```

---------------------------------------------------------------------------------------------------------

## 审核拒绝

> 接口名: `/ShopsRest/checkReject`

### 入参

-------------------------
|属性名称|类型|例子|说明| 
|--------|----|----|----|
|shopsId|int|15|店铺ID|
-----------------------------

### 返回

```json

{
  "code": 200,
  "message": "操作成功"
}

```


---------------------------------------------------------------------------------------------------------

## 根据品牌id，获取品牌供应商关系（可用的供应商，并且是合同有效的）

> 接口名: `/supplier/supplier/selectSupplierByBrandId`

### 入参
```json
{
    "brandId":1409
}

```

-------------------------
|属性名称|类型|例子|说明| 
|--------|----|----|----|
|brandId|int|15|品牌ID|
-----------------------------

### 返回

```json

{
  "code": 200,
  "data": {
    "list": [
      {
        "agreementEndTime": 1456675200,
        "brandId": 1409,
        "supplierId": 1301,
        "supplierName": "腾讯"
      },
      {
        "agreementEndTime": 1477843200,
        "brandId": 1409,
        "supplierId": 1147,
        "supplierName": "北京尚视科技有限公司"
      }
    ]
  },
  "message": "操作成功"
}

```
## 查询所有已经审核通过的店铺

> 接口名: `/ShopsRest/selectCheckPassShopsByName`

### 入参
```json
{
    "idName":"速写CROQUIS"
}
or
{

}

```
### 注意 入参为`{}`,查询所有店铺
-------------------------
|属性名称|类型|例子|说明| 
|--------|----|----|----|
|idName|String|速写CROQUIS|店铺名称|
-----------------------------

### 返回

```json

{
  "code": 200,
  "data": [
    {
      "checkStatus": 0,
      "createTime": "",
      "id": 22,
      "shopNature": 0,
      "shopsType": 0,
      "status": 0,
      "text": "速写CROQUIS",
      "updateTime": ""
    }
  ],
  "message": "操作成功"
}

```
