# 店铺审核接口服务定义
---------------------

## 添加店铺审核

> 接口名：`/ShopsCheckRest/addCheckShop`

### 入参
``` json
{
 "shopsId":15,
 "shopName":"得宝旗舰店",
 "shopNature":1,
 "shopDomain":"debao",
 "shopRelation":[{
	"brandId":355,
	"supplierId":310,
	"agreementEndTime":1485792000,
	"method":"add"
},
{
	"brandId":178,
	"supplierId":480,
	"agreementEndTime":1459353600,
	"method":"del"
}],
"createPid":"1"
}
```
-------------------------
|属性名称|类型|例子|说明| 
|--------|----|----|----|
|shopsId|int|15|店铺ID|
|shopName|String|得宝旗舰店|店铺名称|
|shopNature|int|1|店铺性质(1 旗舰店 2 专卖店)|
|shopDomain|String|debao|店铺域名|
|shopRelation|JSON数组|||
|createPid|int|1|创建人ID|
|shopsType|int|1|店铺模式(1 单品店 2 多品店)|
|shopLogo|String|http://img11.static.yhbimg.com/yhb-img01/2015/09/11/02/01f42dff5d5bd383af1025eea1218cbccc.jpg?imageView/{mode}/w/{width}/h/{height}|店铺logo|
|shopIntro|String|秉承以设计为核心的创新理念，用专业的思维方式将自然与科技、传统与革新、技艺与时尚三者良好融合，着重面料材质与软式廓型的品质互动，更好的诠释“less is more”的设计理念。|店铺简介|
|websiteUrl|JSON数组|["www.paperworks.com.cn"]||
|otherUrl|JSON数组|["www.paperworks.com.cn","https:\/\/jnby.tmall.com\/"]||
|shopAddress|JSON数组|||
|status|int|0|状态(1 开启 0 关闭)|
|createTime|int|1441936854|添加时间|
|updateTime|int|1442312299|修改时间|

注意：入参中`shopRelation`的json格式，如下：
```javascript
[{
	"brandId":355,
	"supplierId":310,
	"agreementEndTime":1485792000,
	"method":"add"
},
{
	"brandId":178,
	"supplierId":480,
	"agreementEndTime":1459353600,
	"method":"del"
}]
```
`websiteUrl`的json格式，如下：
```javascript
["网址1","网址2"]
```
`otherUrl`的json格式，如下：
```javascript
["网址1","网址2"]
```
`shopAddress`的json格式，如下：
```javascript
["地址1","地址2"]
```
---------------------

### 返回

``` json
{
  "code":400
  "message":"shopsId is required"
}
{
  "code":400
  "message":"shopName is required"
}
{
  "code":400
  "message":"shopNature is required"
}
{
  "code":400
  "message":"shopDomain is required"
}
{
  "code":400
  "message":"shopRelation is required"
}
{
  "code":400
  "message":"createPid is required"
}
{
  "code":400
  "message":"店铺已经在审核中"
}
{
  "code":200
  "message":"操作成功"
}
```


## 获取查看审核详情
> 接口名： `/ShopsCheckRest/getCheckShopInfo`

### 入参
```json
{
 "shopsId":20
}
```
-------------------------
|属性名称|类型|例子|说明| 
|--------|----|----|----|
|shopsId|int|15|店铺ID|
---------------------------

### 返回

```json
{
  "code":400
  "message":"店铺id有误"
}
{
  "code":500
  "message":"暂无数据"
}
{
  "code": 200,
  "data": {
    "createPid": 1,
    "createTime": 1454205517,
    "examineStatus": 0,
    "isRead": 1,
    "operationStatus": 1,
    "otherUrl": "",
    "shopAddress": "",
    "shopDomain": "debao",
    "shopIntro": "",
    "shopLogo": "",
    "shopName": "得宝旗舰店",
    "shopNature": 0,
    "shopRelation": "[{\"agreementEndTime\":1485792000,\"brandId\":355,\"method\":\"add\",\"supplierId\":310},{\"agreementEndTime\":1459353600,\"brandId\":178,\"method\":\"del\",\"supplierId\":480}]",
    "shopsId": 15,
    "shopsType": 1,
    "status": 0,
    "updateTime": 1454205517,
    "websiteUrl": ""
  },
  "message": "ok"
}

```

## 审核通过
> 接口名： `/ShopsCheckRest/allowShop`

### 入参
```json
{
 "shopsId":15
}
```
-------------------------
|属性名称|类型|例子|说明| 
|--------|----|----|----|
|shopsId|int|15|店铺ID|
---------------------------

### 返回

```json
{
  "code":400
  "message":"店铺信息有误"
}
{
  "code":500
  "message":"没有待审核的信息"
}
{
  "code":500
  "message":"更新店铺信息失败"
}
{
  "code":200
  "message":"更新成功"
}
```

## 审核驳回

> 接口名：`/ShopsCheckRest/rejectShop`

### 入参
```json{
 "shopsId":15
}
```
-------------------------
|属性名称|类型|例子|说明| 
|--------|----|----|----|
|shopsId|int|15|店铺ID|
-------------------

### 返回

```json
{
  "code":400,
  "message":"店铺信息有误"
}
{
  "code":500,
  "message":"没有待审核的信息"
}
{
  "code":500,
  "message":"操作失败"
}
{
  "code":200,
  "message":"操作成功",
}
```

